@@ -1,16 +1,21 @@
 import time
-from sklearn.metrics import accuracy_score
+
 import numpy as np
 import pandas as pd
-from luciferml.supervised.utils.encoder import encoder
-from luciferml.supervised.utils.predPreprocess import pred_preprocess
-from luciferml.supervised.utils.dimensionalityReduction import dimensionalityReduction
-from luciferml.supervised.utils.classificationPredictor import classificationPredictor
+from IPython.display import display
+from luciferml.supervised.utils.classificationPredictor import \
+    classificationPredictor
+from luciferml.supervised.utils.configs import *
 from luciferml.supervised.utils.confusionMatrix import confusionMatrix
-from luciferml.supervised.utils.kfold import kfold
+from luciferml.supervised.utils.dimensionalityReduction import \
+    dimensionalityReduction
+from luciferml.supervised.utils.encoder import encoder
 from luciferml.supervised.utils.hyperTune import hyperTune
-from luciferml.supervised.utils.sparseCheck import sparseCheck
 from luciferml.supervised.utils.intro import intro
+from luciferml.supervised.utils.kfold import kfold
+from luciferml.supervised.utils.predPreprocess import pred_preprocess
+from luciferml.supervised.utils.sparseCheck import sparseCheck
+from sklearn.metrics import accuracy_score
 
 
 class Classification:
@@ -40,10 +45,11 @@ class Classification:
                  tune_mode=1,
                  smote='n',
                  k_neighbors=1,
-                 dropout_rate=0
+                 dropout_rate=0,
+                 verbose=False
                  ):
         """
-        Encode Categorical Data then Applies SMOTE , Splits the features and labels in training and validation sets with test_size = .2 , scales self.X_train, X_val using StandardScaler.
+        Encode Categorical Data then Applies SMOTE , Splits the features and labels in training and validation sets with test_size = .2 , scales self.X_train, self.X_val using StandardScaler.
         Fits every model on training set and predicts results find and plots Confusion Matrix,
         finds accuracy of model applies K-Fold Cross Validation
         and stores accuracy in variable name accuracy and model name in self.classifier name and returns both as a tuple.
@@ -65,7 +71,6 @@ class Classification:
                                 perc - Perceptron
                                 pass - Passive Aggressive Classifier
                                 ridg - Ridge Classifier
-                                ridgCV - Ridge Classifier with Cross Validation
                                 svm -SupportVector Machine
                                 knn - K-Nearest Neighbours
                                 dt - Decision Trees
@@ -79,6 +84,7 @@ class Classification:
                                 cat - CatBoost Classifier
                                 xgb- XGBoost self.Classifier
                                 ann - Artificial Neural Network
+                                all - Applies all above classifiers
             params : dict
                         contains parameters for model
             tune : boolean
@@ -135,6 +141,8 @@ class Classification:
                 Whether to apply SMOTE. Default = 'y'
             k_neighbors : int
                 No. of neighbours for SMOTE. Default = 1
+            verbose : boolean
+                Verbosity of models. Default = False
 
         Example:
 
@@ -181,6 +189,7 @@ class Classification:
         self.rerun = False
         self.smote = smote
         self.k_neighbors = k_neighbors
+        self.verbose = verbose
 
         self.accuracy_scores = {}
         self.reg_result = {}
@@ -190,9 +199,15 @@ class Classification:
         self.classifier_name = ''
         self.sc = 0
 
+        self.kfoldacc = []
+        self.acc = []
+        self.bestacc = []
+        self.bestparams = []
+        self.result_df = pd.DataFrame(index=classifiers.values())
+
     def fit(self, features, labels):
         """[Takes Features and Labels and Encodes Categorical Data then Applies SMOTE , Splits the features and labels in training and validation sets with test_size = .2
-        scales X_train, X_val using StandardScaler.
+        scales X_train, self.X_val using StandardScaler.
         Fits every model on training set and predicts results,
         finds accuracy of model applies K-Fold Cross Validation
         and stores its accuracies in a dictionary containing Model name as Key and accuracies as values and returns it
@@ -204,18 +219,17 @@ class Classification:
         """
         self.features = features
         self.labels = labels
-
         # Time Function ---------------------------------------------------------------------
 
-        start = time.time()
+        self.start = time.time()
         intro()
         print("Started LuciferML \n")
         if not self.rerun:
             # CHECKUP ---------------------------------------------------------------------
             if not isinstance(self.features, pd.DataFrame) and not isinstance(self.labels, pd.Series):
                 print('TypeError: This Function take features as Pandas Dataframe and labels as Pandas Series. Please check your implementation.\n')
-                end = time.time()
-                print(end - start)
+                self.end = time.time()
+                print(self.end - self.start)
                 return
 
             # Encoding ---------------------------------------------------------------------
@@ -227,27 +241,31 @@ class Classification:
                 self.features, self.labels)
 
             # Preprocessing ---------------------------------------------------------------------
-            self.X_train, X_val, self.y_train, y_val, self.sc = pred_preprocess(
+            self.X_train, self.X_val, self.y_train, self.y_val, self.sc = pred_preprocess(
                 self.features, self.labels, self.test_size, self.random_state, self.smote, self.k_neighbors)
 
             # Dimensionality Reduction---------------------------------------------------------------------
-            self.X_train, X_val = dimensionalityReduction(
-                self.lda, self.pca, self.X_train, X_val, self.y_train,
-                self.n_components_lda, self.n_components_pca, self.pca_kernel, start)
+            self.X_train, self.X_val = dimensionalityReduction(
+                self.lda, self.pca, self.X_train, self.X_val, self.y_train,
+                self.n_components_lda, self.n_components_pca, self.pca_kernel, self.start)
 
         # Models ---------------------------------------------------------------------
-        if self.predictor == 'ann':
+        if self.predictor == 'all':
+            self._fitall()
+            return
+        elif self.predictor == 'ann':
             self.parameters, self.classifier, self.classifier_wrap = classificationPredictor(
-                self.predictor, self.params, self.X_train, X_val, self.y_train, y_val, self.epochs, self.hidden_layers,
+                self.predictor, self.params, self.X_train, self.X_val, self.y_train, self.y_val, self.epochs, self.hidden_layers,
                 self.input_activation, self.output_activation, self.loss,
                 self.batch_size, self.metrics, self.validation_split, self.optimizer,
-                self.output_units, self.input_units, self.tune_mode, self.dropout_rate
-            )
+                self.output_units, self.input_units, self.tune_mode, self.dropout_rate, verbose=self.verbose)
+
         else:
             self.parameters, self.classifier = classificationPredictor(
-                self.predictor, self.params, self.X_train, X_val, self.y_train, y_val, self.epochs, self.hidden_layers,
+                self.predictor, self.params, self.X_train, self.X_val, self.y_train, self.y_val, self.epochs, self.hidden_layers,
                 self.input_activation, self.output_activation, self.loss,
-                self.batch_size, self.metrics, self.validation_split, self.optimizer, self.output_units, self.input_units, self.tune_mode
+                self.batch_size, self.metrics, self.validation_split, self.optimizer, self.output_units, self.input_units, self.tune_mode,
+                verbose=self.verbose
             )
 
         try:
@@ -260,20 +278,20 @@ class Classification:
         print('Model Training Done [', u'\u2713', ']\n')
         print('Predicting Data [*]\n')
         try:
-            self.y_pred = self.classifier.predict(X_val)
+            self.y_pred = self.classifier.predict(self.X_val)
             print('Data Prediction Done [', u'\u2713', ']\n')
+            if self.predictor == 'ann':
+                self.y_pred = (self.y_pred > 0.5).astype("int32")
         except Exception as error:
             print('Prediction Failed with error: ', error,  '\n')
 
         # Confusion Matrix --------------------------------------------------------------
-        if self.predictor == 'ann':
-            self.y_pred = (self.y_pred > 0.5).astype("int32")
-        confusionMatrix(self.y_pred, y_val)
+        confusionMatrix(self.y_pred, self.y_val)
 
         # Accuracy ---------------------------------------------------------------------
         print('''Evaluating Model Performance [*]''')
         try:
-            self.accuracy = accuracy_score(y_val, self.y_pred)
+            self.accuracy = accuracy_score(self.y_val, self.y_pred)
             print('Validation Accuracy is :', self.accuracy)
             print('Evaluating Model Performance [', u'\u2713', ']\n')
         except Exception as error:
@@ -299,16 +317,91 @@ class Classification:
             self.__tuner()
 
         print('Complete [', u'\u2713', ']\n')
-        end = time.time()
-        print('Time Elapsed : ', end - start, 'seconds \n')
+        self.end = time.time()
+        print('Time Elapsed : ', self.end - self.start, 'seconds \n')
 
-    def __tuner(self):
+    def _fitall(self):
+        print('Training All Classifiers [*]')
+        for index, self.predictor in enumerate(classifiers):
+            if not self.predictor == 'ann':
+                self.parameters, self.classifier = classificationPredictor(
+                    self.predictor, self.params, self.X_train, self.X_val, self.y_train, self.y_val, self.epochs, self.hidden_layers,
+                    self.input_activation, self.output_activation, self.loss,
+                    self.batch_size, self.metrics, self.validation_split, self.optimizer, self.output_units, self.input_units, self.tune_mode, all_mode=True, verbose=self.verbose
+                )
+            elif self.predictor == 'ann':
+                self.parameters, self.classifier, self.classifier_wrap = classificationPredictor(
+                    self.predictor, self.params, self.X_train, self.X_val, self.y_train, self.y_val, self.epochs, self.hidden_layers,
+                    self.input_activation, self.output_activation, self.loss,
+                    self.batch_size, self.metrics, self.validation_split, self.optimizer,
+                    self.output_units, self.input_units, self.tune_mode, self.dropout_rate, all_mode=True, verbose=self.verbose
+                )
+            try:
+
+                if not self.predictor == 'ann':
+                    self.classifier.fit(self.X_train, self.y_train)
+            except Exception as error:
+                print(classifiers[self.predictor],
+                      'Model Train Failed with error: ', error, '\n')
+            try:
+                self.y_pred = self.classifier.predict(self.X_val)
+            except Exception as error:
+                print(classifiers[self.predictor],
+                      'Data Prediction Failed with error: ', error,  '\n')
+            if self.predictor == 'ann':
+                self.y_pred = (self.y_pred > 0.5).astype("int32")
+
+            # Accuracy ---------------------------------------------------------------------
+            try:
+                self.accuracy = accuracy_score(self.y_val, self.y_pred)
+                self.acc.append(self.accuracy*100)
+            except Exception as error:
+                print(classifiers[self.predictor],
+                      'Evaluation Failed with error: ', error, '\n')
+
+            # K-Fold ---------------------------------------------------------------------
+            if self.predictor == 'ann':
+                self.classifier_name, self.kfold_accuracy = kfold(
+                    self.classifier_wrap,
+                    self.predictor, self.X_train, self.y_train, self.cv_folds, all_mode=True
+                )
+            else:
+                self.classifier_name, self.kfold_accuracy = kfold(
+                    self.classifier,
+                    self.predictor,
+                    self.X_train, self.y_train, self.cv_folds, all_mode=True
+                )
+            self.kfoldacc.append(self.kfold_accuracy)
+            # GridSearch ---------------------------------------------------------------------
+            if not self.predictor == 'nb' and self.tune:
+                self.__tuner(all_mode=True)
+            if self.predictor == 'nb':
+                self.best_params = ''
+                self.best_accuracy = self.kfold_accuracy
+        self.result_df['Accuracy'] = self.acc
+        self.result_df['KFold Accuracy'] = self.kfoldacc
+        if self.tune:
+            self.result_df['Best Parameters'] = self.bestparams
+            self.result_df['Best Accuracy'] = self.bestacc
+
+        display(self.result_df)
+        print('Complete [', u'\u2713', ']\n')
+        self.end = time.time()
+        print('Time Elapsed : ', self.end - self.start, 'seconds \n')
+
+    def __tuner(self, all_mode=False):
+        if not all_mode:
+            print(
+                'Applying Grid Search Cross validation on Mode {} [*]'.format(self.tune_mode))
         if self.predictor == 'ann':
-            self.best_params = hyperTune(
-                self.classifier_wrap, self.parameters, self.X_train, self.y_train, self.cv_folds, self.tune_mode)
+            self.best_params, self.best_accuracy = hyperTune(
+                self.classifier_wrap, self.parameters, self.X_train, self.y_train, self.cv_folds, self.tune_mode, all_mode=all_mode)
         else:
-            self.best_params = hyperTune(
-                self.classifier, self.parameters, self.X_train, self.y_train, self.cv_folds, self.tune_mode)
+            self.best_params, self.best_accuracy = hyperTune(
+                self.classifier, self.parameters, self.X_train, self.y_train, self.cv_folds, self.tune_mode, all_mode=all_mode)
+
+        self.bestparams.append(self.best_params)
+        self.bestacc.append(self.best_accuracy*100)
 
     def result(self):
         """[Makes a dictionary containing Classifier Name, K-Fold CV Accuracy, RMSE, Prediction set.]
@@ -323,11 +416,15 @@ class Classification:
                         - "YPred" - Array for Prediction set
                         ]
         """
-        self.reg_result['Classifier'] = self.classifier_name
-        self.reg_result['Accuracy'] = self.kfold_accuracy
-        self.reg_result['YPred'] = self.y_pred
+        if not self.predictor == 'all':
+            self.reg_result['Classifier'] = self.classifier_name
+            self.reg_result['Accuracy'] = self.kfold_accuracy
+            self.reg_result['YPred'] = self.y_pred
 
-        return self.reg_result
+            return self.reg_result
+        if self.predictor == 'all':
+            print('[Error] This method is only applicable on single predictor')
+            return
 
     def predict(self, X_test):
         """[Takes test set and returns predictions for that test set]
@@ -338,12 +435,16 @@ class Classification:
         Returns:
             [Array]: [Predicted set for given test set]
         """
-        X_test = np.array(X_test)
-        if X_test.ndim == 1:
-            print('''Input Array has only 1-Dimension but 2-Dimension was expected. 
-                  Reshaping it to 2-Dimension''')
-            X_test = X_test.reshape(1, -1)
+        if not self.predictor == 'all':
+            X_test = np.array(X_test)
+            if X_test.ndim == 1:
+                print('''Input Array has only 1-Dimension but 2-Dimension was expected. 
+                    Reshaping it to 2-Dimension''')
+                X_test = X_test.reshape(1, -1)
 
-        y_test = self.regressor.predict(self.sc.transform(X_test))
+            y_test = self.regressor.predict(self.sc.transform(X_test))
 
-        return y_test
+            return y_test
+        if self.predictor == 'all':
+            print('[Error] This method is only applicable on single predictor')
+            return
